#! /bin/bash
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# --------------------------------------------------------------------------
# Restarts the the various services as denoted by the given agent type.
#
# @param
#	agent_type=<common, platform>
#			Common Agent or Platform Agent.
#
#			The following services will be restarted for Common Agent:
#			1. endpoint.sh (common agent) - stop
#			2. cimserver - stop
#			3. tier1slp - stop
#			4. slp - stop
#
#			5. slp - start
#			6. tier1slp - start
#			7. cimserver - start
#			8. endpoint.sh (common agent) - start
#
#			The following services will be restarted for Platform Agent:
#			1. cimserver - stop
#			2. tier1slpinst - stop
#			3. cimlistenerd - stop
#			4. slp - stop
#
#			5. slp - start
#			6. cimlistenerd - start
#			7. tier1slpinst - start
#			8. cimserverd start
#
# @return
#	result=success
#			Overall operation succeed. No errors returned by the start command
#
#	result=fail
#			Overall operation failed. At least one command was not found
#			or at least one start command failed. The following values can be
# 			set to provide more detail:
#
#				slp_RC={start_fail, notfound}
#				common_RC={start_fail, notfound}
#				cimlistener_RC={start_fail, notfound}
#				cimserver_RC={start_fail, notfound}
#				tier1slp_RC={start_fail, notfound}
#---------------------------------------------------------------------------

agent_type="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

# -----------------------------------------------
# SLP common to both platform and common agents
# -----------------------------------------------

if [ -e /etc/init.d/ibmsa ]; then
	slp_stop_cmd="/etc/init.d/ibmsa stop"
	slp_start_cmd="/etc/init.d/ibmsa start"
else
	if [ -e /etc/init.d/paslpd ]; then
		slp_stop_cmd="/etc/init.d/paslpd stop"
		slp_start_cmd="/etc/init.d/paslpd start"
	else
		echo "result=fail,slp_RC=notfound"
		exit 0
	fi
fi


# -----------------------------------------------
# This service should be restarted for Platform 
# Agent only
# -----------------------------------------------

if [ "$agent_type" = "platform" ]; then

	if [ ! -e /etc/init.d/cimlistenerd ]; then
			echo "result=fail,cimlistenerd_RC=notfound"
			exit 0
	else
			cimlistener_stop_cmd="/etc/init.d/cimlistenerd stop"
			cimlistener_start_cmd="/etc/init.d/cimlistenerd start"
	fi
fi

# -----------------------------------------------
# These services should be restarted for both 
# Platform Agent and Common Agent
# -----------------------------------------------

if [ ! -e /etc/init.d/cimserverd ]; then
		echo "result=fail,cimserverd_RC=notfound"
		exit 0
else
		cimserver_stop_cmd="/etc/init.d/cimserverd stop"
		cimserver_start_cmd="/etc/init.d/cimserverd start"
fi

if [ ! -e /etc/init.d/tier1slpinst ]; then
		echo "result=fail,cimtierslp_RC=notfound"
		exit 0
else
		cimtierslp_stop_cmd="/etc/init.d/tier1slpinst stop"
		cimtierslp_start_cmd="/etc/init.d/tier1slpinst start"
		cimtierslp_status_cmd="/etc/init.d/tier1slpinst status"
fi


# -----------------------------------------------
#
# Let's stop and start the services for the
# Common Agent
#
# -----------------------------------------------

if [ "$agent_type" = "common" ]; then
		
		# ---------------------------------------------
		# Watchdog added into DS 6.3 agents
		#
		# ---------------------------------------------
		if [ -e /etc/init.d/ibmpawatchdogd ]; then
			/etc/init.d/ibmpawatchdogd stop > /dev/null 2>&1
		fi
		
		/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh stop > /dev/null 2>&1
		# -----------------------------------------
		# Let's don't check RC here for now
		# We do not care if service already stopped
		# -----------------------------------------
		
		$cimserver_stop_cmd > /dev/null 2>&1
		$cimtierslp_stop_cmd > /dev/null 2>&1
		$slp_stop_cmd > /dev/null 2>&1
		
		$slp_start_cmd > /dev/null 2>&1
		RC=$?
		if [ "$RC" != "0" ]; then
        	echo "result=fail,slp_RC=start_fail"
        	exit 0
        fi

		# See RTC Defect 525
		$cimtierslp_start_cmd > /dev/null 2>&1 &
		for i in 1 2 3 4 5
		do
			sleep 5
			cimtierslp_status="$($cimtierslp_status_cmd | grep -i "TIER1SLP running")"
			if [ "x$cimtierslp_status" = "x" ]; then
				# -----------------------------------------
				# service is not reported as running
				# Do nothing just continue with the loop
				# -----------------------------------------
				echo "dummy" > /dev/null
			else
				break
			fi
		if [ "$i" = "5" ]; then
			echo "result=fail,tier1slp_RC=start_fail"
			exit 0
		fi
		done
		
		$cimserver_start_cmd > /dev/null 2>&1
		RC=$?
		if [ "$RC" != "0" ]; then
        	echo "result=fail,cimserver_RC=start_fail"
        	exit 0
        fi
       
		/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh start > /dev/null 2>&1 
		RC=$?
		if [ "$RC" != "0" ]; then
			echo "result=fail,common_RC=start_fail"
			exit 0
		fi
		
		if [ -e /etc/init.d/ibmpawatchdogd ]; then
			/etc/init.d/ibmpawatchdogd start > /dev/null 2>&1
			RC=$?
			if [ "$RC" != "0" ]; then
				echo "result=fail,watchdog_RC=start_fail"
				exit 0
			fi
		fi
		
		# --------------------------------------------
		#
		# We are done with starting the Common Agent
		#
		# --------------------------------------------
		echo "result=success"
		exit 0
fi

if [ "$agent_type" = "platform" ]; then

		# -----------------------------------------
		# Let's don't check RC here for now
		# We do not care if service already stopped
		# -----------------------------------------
		if [ -e /etc/init.d/ibmpawatchdogd ]; then
			/etc/init.d/ibmpawatchdogd stop > /dev/null 2>&1
		fi
		
		$cimserver_stop_cmd > /dev/null 2>&1
		$cimtierslp_stop_cmd > /dev/null 2>&1
		$cimlistener_stop_cmd > /dev/null 2>&1
		$slp_stop_cmd > /dev/null 2>&1
		
		$slp_start_cmd > /dev/null 2>&1
		RC=$?
		if [ "$RC" != "0" ]; then
        	echo "result=fail,slp_RC=start_fail"
        	exit 0
        fi
        
        $cimlistener_start_cmd > /dev/null 2>&1
		RC=$?
		if [ "$RC" != "0" ]; then
        	echo "result=fail,cimlistener_RC=start_fail"
        	exit 0
        fi

		# See RTC Defect 525
		$cimtierslp_start_cmd > /dev/null 2>&1 &
		for i in 1 2 3 4 5
		do
			sleep 5
			cimtierslp_status="$($cimtierslp_status_cmd | grep -i "TIER1SLP running")"
			if [ "x$cimtierslp_status" = "x" ]; then
				# -----------------------------------------
				# service is not reported as running
				# Do nothing just continue with the loop
				# -----------------------------------------
				echo "dummy" > /dev/null
			else
				break
			fi
		if [ "$i" = "5" ]; then
			echo "result=fail,tier1slp_RC=start_fail"
			exit 0
		fi
		done

		$cimserver_start_cmd > /dev/null 2>&1
		RC=$?
		if [ "$RC" != "0" ]; then
        	echo "result=fail,cimserver_RC=start_fail"
        	exit 0
        fi
		
		if [ -e /etc/init.d/ibmpawatchdogd ]; then
			/etc/init.d/ibmpawatchdogd start > /dev/null 2>&1
			RC=$?
			if [ "$RC" != "0" ]; then
				echo "result=fail,watchdog_RC=start_fail"
				exit 0
			fi
		fi
		
		# --------------------------------------------
		#
		# We are done with starting the Platform Agent
		#
		# --------------------------------------------
		echo "result=success"
		exit 0

fi
